@@ -1,4 +1,4 @@
-#!/usr/bin/bash
+#!/bin/bash
 #
 #   build_references.sh - Warn about files containing references to build directories
 #
@@ -37,13 +37,5 @@ warn_build_references() {
 			printf '%s\n' "${refs[@]#"$pkgdir/"}" >&2
 		fi
 	done
-
-	# Check for Windows-style MSYS2 root path
-	if find "${pkgdir}" -type f -print0 | xargs -0 grep -iFqI "$(cygpath -m /)" ; then
-		warning "$(gettext "Package contains reference to %s")" "\$(cygpath -m /)"
-	fi
-	if find "${pkgdir}" -type f -print0 | xargs -0 grep -iFqI "$(cygpath -w /)" ; then
-		warning "$(gettext "Package contains reference to %s")" "\$(cygpath -w /)"
-	fi
 	return 0
 }
