@@ -1,4 +1,4 @@
-#!/usr/bin/bash
+#!/bin/bash
 #
 #   git.sh - function for handling the download and "extraction" of Git sources
 #
@@ -24,6 +24,7 @@ LIBMAKEPKG_SOURCE_GIT_SH=1
 
 MAKEPKG_LIBRARY=${MAKEPKG_LIBRARY:-'/usr/share/makepkg'}
 
+source "$MAKEPKG_LIBRARY/util/error.sh"
 source "$MAKEPKG_LIBRARY/util/message.sh"
 source "$MAKEPKG_LIBRARY/util/pkgbuild.sh"
 
@@ -48,26 +49,36 @@ download_git() {
 
 	if [[ ! -d "$dir" ]] || dir_is_empty "$dir" ; then
 		msg2 "$(gettext "Cloning %s %s repo...")" "${repo}" "git"
-		if ! git clone --origin=origin ${GITFLAGS:---mirror} "$url" "$dir"; then
+		if ! git clone --origin=origin --mirror "$url" "$dir"; then
 			error "$(gettext "Failure while downloading %s %s repo")" "${repo}" "git"
 			plainerr "$(gettext "Aborting...")"
 			exit 1
 		fi
 	elif (( ! HOLDVER )); then
 		cd_safe "$dir"
+		# When invoking git on a potentially bare repository, we should pass -c safe.bareRepository=all
+		# to avoid breaking when the option is globally set to explicit
+
 		# Make sure we are fetching the right repo
-		local remote_url="$(git config --get remote.origin.url)"
+		local remote_url="$(git -c safe.bareRepository=all config --get remote.origin.url)"
 		if [[ "${url%%.git}" != "${remote_url%%.git}" ]] ; then
 			error "$(gettext "%s is not a clone of %s")" "$dir" "$url"
 			plainerr "$(gettext "Aborting...")"
-			exit 1
+			exit $E_NOT_A_CLONE_OF
 		fi
 		msg2 "$(gettext "Updating %s %s repo...")" "${repo}" "git"
-		if ! git fetch --all -p; then
+		if ! git -c safe.bareRepository=all fetch --all -p; then
 			# only warn on failure to allow offline builds
 			warning "$(gettext "Failure while updating %s %s repo")" "${repo}" "git"
 		fi
 	fi
+
+	# Sanitize the cloned repo
+	# $GIT_DIR/info/attributes overrides .gitattributes, and thus no files in the repository
+	# can be altered by git features like export-subst or export-ignore
+	local MAKEPKG_GIT_DIR="$(git -c safe.bareRepository=all -C "$dir" rev-parse --absolute-git-dir)"
+	mkdir -p "$MAKEPKG_GIT_DIR/info"
+	echo "* -export-subst -export-ignore" > "$MAKEPKG_GIT_DIR/info/attributes"
 }
 
 extract_git() {
@@ -150,7 +161,7 @@ calc_checksum_git() {
 	case ${fragment%%=*} in
 		tag|commit)
 			fragval=${fragment##*=}
-			sum=$(git -c core.abbrev=no -C "$dir" archive --format tar "$fragval" | "${integ}sum" 2>&1) || ret=1
+			sum=$(GIT_CONFIG_GLOBAL=/dev/null GIT_CONFIG_SYSTEM=/dev/null git -c core.abbrev=no -C "$dir" archive --format tar "$fragval" | "${integ}sum" 2>&1) || ret=1
 			sum="${sum%% *}"
 			;;
 		*)
