@@ -1,4 +1,4 @@
-#!/usr/bin/bash
+#!/bin/bash
 #
 #   pkgbuild.sh - functions to extract information from PKGBUILD files
 #
@@ -134,7 +134,7 @@ get_pkgbuild_attribute() {
 }
 
 get_pkgbuild_all_split_attributes() {
-	local attrname=$1 outputvar=$2 all_list list
+	local attrname=$1 outputvar=$2 all_list list name a
 
 	if extract_global_variable "$attrname" 1 list; then
 		all_list+=("${list[@]}")
@@ -166,11 +166,7 @@ get_pkgbuild_all_split_attributes() {
 ##
 get_full_version() {
 	if (( epoch > 0 )); then
-		if [[ -n $MSYSTEM ]]; then
-			printf "%s\n" "${epoch}~${pkgver}-${pkgrel}"
-		else
-			printf "%s\n" "$epoch:$pkgver-$pkgrel"
-		fi
+		printf "%s\n" "$epoch:$pkgver-$pkgrel"
 	else
 		printf "%s\n" "$pkgver-$pkgrel"
 	fi
